/**
 * @module ApFormMixin
 */
'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactDom = require('react-dom');

var _reactDom2 = _interopRequireDefault(_reactDom);

var _defaults = require('defaults');

var _defaults2 = _interopRequireDefault(_defaults);

var _stringcase = require('stringcase');

var _stringcase2 = _interopRequireDefault(_stringcase);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/** @lends ApFormMixin */
var ApFormMixin = {

  // --------------------
  // Custom
  // --------------------

  $apFormMixin: true,

  /**
   * Handle change of form input
   * @param {object} e - Input change event.
   */
  handleFormChange: function handleFormChange(e) {
    var s = this;
    var props = s.props;
    var _e$target = e.target;
    var name = _e$target.name;
    var value = _e$target.value;

    var values = Object.assign({}, props.formValues, _defineProperty({}, name, value));

    if (props.onFormChange) {
      e = e || {};
      e.target = e.target || _reactDom2.default.findDOMNode(s);
      e.form = values;
      props.onFormChange(e);
    }
  },


  /**
   * Handle form submit.
   * @param {object} e - Submit event.
   */
  handleFormSubmit: function handleFormSubmit(e) {
    var s = this;
    var props = s.props;


    var values = props.formValues;
    if (props.onFormSubmit) {
      e = e || {};
      e.target = e.target || _reactDom2.default.findDOMNode(s);
      e.form = values;
      props.onFormSubmit(e);
    }
  },


  /**
   * Handle form cancel.
   * @param {object} e - Submit event.
   */
  handleFormCancel: function handleFormCancel(e) {
    var s = this;
    var props = s.props;


    var values = props.formValues;
    if (props.onFormCancel) {
      e = e || {};
      e.target = e.target || _reactDom2.default.findDOMNode(s);
      e.form = values;
      props.onFormCancel(e);
    }
  },


  /**
   * Get a form value.
   * @param {string} name - Name of the value.
   * @returns {*} - Value
   */
  getFormValue: function getFormValue(name) {
    var s = this;
    var values = s.getFormValues();
    if (!values) {
      return undefined;
    }
    return values && values[name];
  },


  /**
   * Get form values.
   * @returns {string}
   */
  getFormValues: function getFormValues() {
    var s = this;
    var formValues = s.props.formValues;

    return s.formatFormValues(formValues || null);
  },


  /**
   * Get a form id.
   * @param {string} name
   * @returns {string}
   */
  getFormId: function getFormId(name) {
    var s = this;
    var formPrefix = s.props.formPrefix;

    return [formPrefix || 'ap-form', _stringcase2.default.spinalcase(name)].join('-');
  },


  /**
   * Get a label
   * @param {string} name
   * @returns {string}
   */
  getFormLabel: function getFormLabel(name) {
    var s = this;
    var formLabels = s.props.formLabels;

    var label = (formLabels || {})[name];
    if (!label) {
      console.warn('[ApFormMixin] Label not found with name: ' + name);
      label = name;
    }
    return label;
  },


  /**
   * Get a icon
   * @param {string} name
   * @returns {string}
   */
  getFormIcon: function getFormIcon(name) {
    var s = this;
    var formIcons = s.props.formIcons;

    return (formIcons || {})[name];
  },


  /**
   * Get a placeholder
   * @param {string} name
   * @returns {string}
   */
  getFormPlaceholder: function getFormPlaceholder(name) {
    var s = this;
    var formPlaceholders = s.props.formPlaceholders;

    return (formPlaceholders || {})[name];
  },


  /**
   * Get an image
   * @param {string} name
   * @returns {string}
   */
  getFormImage: function getFormImage(name) {
    var s = this;
    var formImages = s.props.formImages;

    return (formImages || {})[name];
  },


  /**
   * Get an action
   * @param {string} name
   * @returns {string}
   */
  getFormAction: function getFormAction(name) {
    var s = this;
    var formActions = s.props.formActions;

    return (formActions || {})[name];
  },


  /**
   * Wrap as form handler.
   * @param {function} handler - A handler.
   * @param {object} options - Optional setttings
   * @returns {function}
   */
  asFormHandler: function asFormHandler(handler, options) {
    var s = this;
    options = options || {};
    var key = options.key || 'default';
    if (!handler) {
      return null;
    }
    handler.apFormWraps = handler.apFormWraps || {};
    handler.apFormWraps[key] = handler.apFormWraps[key] || function formWrap(e) {
      e = Object.assign(e || {}, {
        form: s.getFormValues()
      }, options);
      handler.call(s, e);
    };
    return handler.apFormWraps[key];
  },


  // --------------------
  // Specs
  // --------------------

  propTypes: {
    formValues: _react.PropTypes.object,
    formLabels: _react.PropTypes.object,
    formIcons: _react.PropTypes.object,
    formImages: _react.PropTypes.object,
    formActions: _react.PropTypes.object,
    formPlaceholders: _react.PropTypes.object,
    formPrefix: _react.PropTypes.string,
    onFormChange: _react.PropTypes.func,
    onFormSubmit: _react.PropTypes.func,
    onFormCancel: _react.PropTypes.func
  },

  getDefaultProps: function getDefaultProps() {
    return {};
  },


  // --------------------
  // Lifecycle
  // --------------------

  componentWillMount: function componentWillMount() {
    var s = this;

    var noop = function noop(value) {
      return value;
    };
    (0, _defaults2.default)(s, {
      formatFormValues: noop
    });
  }
};

exports.default = ApFormMixin;
//# sourceMappingURL=data:application/json;base64,bnVsbA==